@@ -30,7 +30,7 @@
 # Rights Reserved.
 #
 
-"""
+""" 
 Module for accessing the Heliophysics Data Portal (HDP) web services
 https://heliophysicsdata.gsfc.nasa.gov/WebServices/.
 """
@@ -42,7 +42,7 @@ import logging
 from typing import Dict, List, Union
 import requests
 
-from hdpws import __version__, ET_NS, ET_XHTML_NS
+from hdpws import __version__, NAMESPACES
 from hdpws.dateinterval import DateInterval
 from hdpws.resourcetype import ResourceType
 
@@ -599,7 +599,8 @@ class HdpWs:
             result_name: []
         }
 
-        for value in mt_response.findall('.//' + ET_NS + name):
+        for value in mt_response.findall('.//hdp:' + name,
+                                         namespaces=NAMESPACES):
 
             result[result_name].append(value.text)
 
@@ -710,11 +711,11 @@ class HdpWs:
             try:
                 error_element = ET.fromstring(response.text)
                 http_result['ErrorMessage'] = error_element.findall(\
-                    './/' + ET_XHTML_NS + 'p[@class="ErrorMessage"]/' +
-                    ET_XHTML_NS + 'b')[0].tail
+                    './/xhtml:p[@class="ErrorMessage"]/xhtml:b',
+                    namespaces=NAMESPACES)[0].tail
                 http_result['ErrorDescription'] = error_element.findall(\
-                    './/' + ET_XHTML_NS + 'p[@class="ErrorDescription"]/' +
-                    ET_XHTML_NS + 'b')[0].tail
+                    './/xhtml:p[@class="ErrorDescription"]/xhtml:b',
+                    namespaces=NAMESPACES)[0].tail
             except ParseError:
                 pass  # ErrorText is the best we can do
 
